@@ -1,5 +1,5 @@
 package MojoCoreMantainer;
-use Mojo::Base 'Mojo::Role';
+use Mojo::Role;
 
 sub mantaining_mojo {
   say "I'm making improvements for Mojolicious..."
