@@ -1,5 +1,5 @@
 package TestWith;
-use Mojo::Base 'Mojo::Role';
+use Mojo::Role;
 
 sub test_method {
   return 1;
